@@ -10,21 +10,22 @@
 
 #define XC_GGA_X_2D_B86_MGC      124 /* Becke 86 MGC for 2D systems */
 
-#include "maple2c/gga_x_2d_b86_mgc.c"
-
-#define func maple2c_func
-#define XC_DIMENSIONS 2
-#include "work_gga_x.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_x_2d_b86_mgc.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_x_2d_b86_mgc = {
   XC_GGA_X_2D_B86_MGC,
   XC_EXCHANGE,
   "Becke 86 with modified gradient correction for 2D",
   XC_FAMILY_GGA,
   {&xc_ref_Pittalis2009_012503, NULL, NULL, NULL, NULL},
-  XC_FLAGS_2D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-23,
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, work_gga_x, NULL
+  XC_FLAGS_2D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, work_gga, NULL
 };
