@@ -10,22 +10,23 @@
 
 #define XC_GGA_X_LG93  113 /* Lacks & Gordon 93 */
 
-#include "maple2c/gga_x_lg93.c"
-
-#define func xc_gga_x_lg93_enhance
-#include "work_gga_x.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_x_lg93.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_x_lg93 = {
   XC_GGA_X_LG93,
   XC_EXCHANGE,
   "Lacks & Gordon 93",
   XC_FAMILY_GGA,
   {&xc_ref_Lacks1993_4681, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-32,
-  0, NULL, NULL,
-  NULL, NULL, NULL,
-  work_gga_x,
-  NULL
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, work_gga, NULL
 };
 
