@@ -16,13 +16,13 @@ typedef struct{
   double alpha;
 } gga_x_vmt84_params;
 
-static void 
+static void
 gga_x_vmt84_init(xc_func_type *p)
 {
   gga_x_vmt84_params *params;
 
   assert(p != NULL && p->params == NULL);
-  p->params = malloc(sizeof(gga_x_vmt84_params));
+  p->params = libxc_malloc(sizeof(gga_x_vmt84_params));
   params = (gga_x_vmt84_params *) (p->params);
 
   switch(p->info->number){
@@ -40,33 +40,38 @@ gga_x_vmt84_init(xc_func_type *p)
   }
 }
 
-#include "maple2c/gga_x_vmt84.c"
-
-#define func maple2c_func
-#include "work_gga_x.c"
+#include "decl_gga.h"
+#include "maple2c/gga_exc/gga_x_vmt84.c"
+#include "work_gga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_x_vmt84_pbe = {
   XC_GGA_X_VMT84_PBE,
   XC_EXCHANGE,
   "VMT{8,4} with constraint satisfaction with mu = mu_PBE",
   XC_FAMILY_GGA,
   {&xc_ref_Vela2012_144115, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-32,
-  0, NULL, NULL,
-  gga_x_vmt84_init, NULL, 
-  NULL, work_gga_x, NULL
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  gga_x_vmt84_init, NULL,
+  NULL, work_gga, NULL
 };
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_x_vmt84_ge = {
   XC_GGA_X_VMT84_GE,
   XC_EXCHANGE,
   "VMT{8,4} with constraint satisfaction with mu = mu_GE",
   XC_FAMILY_GGA,
   {&xc_ref_Vela2012_144115, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-32,
-  0, NULL, NULL,
-  gga_x_vmt84_init, NULL, 
-  NULL, work_gga_x, NULL
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  gga_x_vmt84_init, NULL,
+  NULL, work_gga, NULL
 };
