@@ -22,16 +22,19 @@ gga_xc_xlyp_init(xc_func_type *p)
   xc_mix_init(p, 4, funcs_id, funcs_coef);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_xc_xlyp = {
   XC_GGA_XC_XLYP,
   XC_EXCHANGE_CORRELATION,
   "XLYP",
   XC_FAMILY_GGA,
   {&xc_ref_Xu2004_2673, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-24,
-  0, NULL, NULL,
-  gga_xc_xlyp_init, 
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  gga_xc_xlyp_init,
   NULL, NULL, NULL, NULL
 };
 
@@ -45,16 +48,19 @@ gga_xc_pbe1w_init(xc_func_type *p)
   xc_mix_init(p, 3, funcs_id, funcs_coef);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_xc_pbe1w = {
   XC_GGA_XC_PBE1W,
   XC_EXCHANGE_CORRELATION,
   "PBE1W",
   XC_FAMILY_GGA,
   {&xc_ref_Dahlke2005_15677, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-24,
-  0, NULL, NULL,
-  gga_xc_pbe1w_init, 
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  gga_xc_pbe1w_init,
   NULL, NULL, NULL, NULL
 };
 
@@ -68,16 +74,19 @@ gga_xc_mpwlyp1w_init(xc_func_type *p)
   xc_mix_init(p, 3, funcs_id, funcs_coef);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_xc_mpwlyp1w = {
   XC_GGA_XC_MPWLYP1W,
   XC_EXCHANGE_CORRELATION,
   "mPWLYP1w",
   XC_FAMILY_GGA,
   {&xc_ref_Dahlke2005_15677, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-24,
-  0, NULL, NULL,
-  gga_xc_mpwlyp1w_init, 
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  gga_xc_mpwlyp1w_init,
   NULL, NULL, NULL, NULL
 };
 
@@ -91,16 +100,19 @@ gga_xc_pbelyp1w_init(xc_func_type *p)
   xc_mix_init(p, 3, funcs_id, funcs_coef);
 }
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_gga_xc_pbelyp1w = {
   XC_GGA_XC_PBELYP1W,
   XC_EXCHANGE_CORRELATION,
   "PBELYP1W",
   XC_FAMILY_GGA,
   {&xc_ref_Dahlke2005_15677, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
-  1e-32,
-  0, NULL, NULL,
-  gga_xc_pbelyp1w_init, 
+  XC_FLAGS_3D | XC_FLAGS_I_HAVE_ALL,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
+  gga_xc_pbelyp1w_init,
   NULL, NULL, NULL, NULL
 };
 
