@@ -14,23 +14,22 @@
 
 #define XC_LDA_C_GOMBAS  24   /* Gombas parametrization       */
 
-#include "maple2c/lda_c_gombas.c"
-
-#define func maple2c_func
+#include "decl_lda.h"
+#include "maple2c/lda_exc/lda_c_gombas.c"
 #include "work_lda.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_lda_c_gombas = {
   XC_LDA_C_GOMBAS,
   XC_CORRELATION,
   "Gombas",
   XC_FAMILY_LDA,
-  {&xc_ref_Gombas1967, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  {&xc_ref_Gombas1965_137, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
   1e-32,
-  0, NULL, NULL,
-  NULL,     /* init */
-  NULL,     /* end  */
-  work_lda, /* lda  */
-  NULL,
-  NULL
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  work_lda, NULL, NULL
 };
