@@ -11,20 +11,22 @@
 
 #define XC_MGGA_C_B88          571 /* Meta-GGA correlation by Becke */
 
-#include "maple2c/mgga_c_b88.c"
-
-#define func maple2c_func
-#include "work_mgga_c.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_c_b88.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_c_b88 = {
   XC_MGGA_C_B88,
   XC_CORRELATION,
   "Meta-GGA correlation by Becke",
   XC_FAMILY_MGGA,
   {&xc_ref_Becke1988_1053, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-24,
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, NULL, work_mgga_c,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, NULL, work_mgga,
 };
