@@ -11,21 +11,23 @@
 
 #define XC_MGGA_C_PKZB          239 /* Perdew, Kurth, Zupan, and Blaha */
 
-#include "maple2c/mgga_c_pkzb.c"
-
-#define func maple2c_func
-#include "work_mgga_c.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_c_pkzb.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_c_pkzb = {
   XC_MGGA_C_PKZB,
   XC_CORRELATION,
   "Perdew, Kurth, Zupan, and Blaha",
   XC_FAMILY_MGGA,
   {&xc_ref_Perdew1999_2544, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
   1e-13, /* densities smaller than 1e-26 give NaNs */
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, NULL, work_mgga_c,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, NULL, work_mgga,
 };
 
