@@ -11,20 +11,22 @@
 
 #define XC_MGGA_X_PBE_GX          576 /* PBE-GX functional of Loos */
 
-#include "maple2c/mgga_x_pbe_gx.c"
-
-#define func maple2c_func
-#include "work_mgga_x.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_x_pbe_gx.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_x_pbe_gx = {
   XC_MGGA_X_PBE_GX,
   XC_EXCHANGE,
   "PBE-GX functional of Loos",
   XC_FAMILY_MGGA,
   {&xc_ref_Loos2017_114108, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-23,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
-  NULL, NULL, work_mgga_x,
+  NULL, NULL, work_mgga,
 };
