@@ -8,22 +8,24 @@
 
 #include "util.h"
 
-#define XC_MGGA_X_TM          540 /* Tao and Mo 2016 */
+#define XC_MGGA_X_TM          540 /* Tao and Mo 2016 exchange */
 
-#include "maple2c/mgga_x_tm.c"
-
-#define func xc_mgga_x_tm_enhance
-#include "work_mgga_x.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_x_tm.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_x_tm = {
   XC_MGGA_X_TM,
   XC_EXCHANGE,
-  "Tao and Mo 2016",
+  "Tao and Mo 2016 exchange",
   XC_FAMILY_MGGA,
   {&xc_ref_Tao2016_073001, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1.0e-23,
-  0, NULL, NULL,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-15,
+  {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
-  NULL, NULL, work_mgga_x,
+  NULL, NULL, work_mgga,
 };
