@@ -11,20 +11,22 @@
 
 #define XC_MGGA_X_VT84          541 /* meta-GGA version of VT{8,4} GGA */
 
-#include "maple2c/mgga_x_vt84.c"
-
-#define func maple2c_func
-#include "work_mgga_x.c"
+#include "decl_mgga.h"
+#include "maple2c/mgga_exc/mgga_x_vt84.c"
+#include "work_mgga.c"
 
+#ifdef __cplusplus
+extern "C"
+#endif
 const xc_func_info_type xc_func_info_mgga_x_vt84 = {
   XC_MGGA_X_VT84,
   XC_EXCHANGE,
   "meta-GGA version of VT{8,4} GGA",
   XC_FAMILY_MGGA,
   {&xc_ref_Campo2012_179, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-23,
-  0, NULL, NULL,
-  NULL, NULL, 
-  NULL, NULL, work_mgga_x,
+  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  1e-14,
+  {0, NULL, NULL, NULL, NULL},
+  NULL, NULL,
+  NULL, NULL, work_mgga,
 };
